@@ -248,7 +248,7 @@ gmag_gs_reset_overlay_at_idle (gpointer data)
 		return FALSE;
 	if (data) {
 		Magnifier *magnifier = MAGNIFIER (data);
-		if (magnifier->priv &&
+		if (magnifier->priv && magnifier->priv->w &&
 		    GTK_WIDGET_REALIZED (magnifier->priv->w)) 
 			if (magnifier->priv->w->window) {
 #ifdef HAVE_OVERLAY
@@ -460,6 +460,10 @@ gmag_gs_use_damage ()
 gboolean
 gmag_gs_use_compositor (Magnifier *magnifier)
 {
+	if (dpy == NULL) {
+		dpy = XOpenDisplay (magnifier->source_display_name); 
+	}
+
 	if (!gmag_gs_use_damage ()) {
 		return FALSE;
 	}
